@@ -1,13 +1,18 @@
 from ._embeddings import AsyncBatchEmbeddings, BatchEmbeddings
 from ._model import PreparedTask
-from ._prompt import FewShotPromptBuilder
+from ._prompt import FewShotPrompt, FewShotPromptBuilder
 from ._responses import AsyncBatchResponses, BatchResponses
+from ._schema import SchemaInferenceInput, SchemaInferenceOutput, SchemaInferer
 
 __all__ = [
     "AsyncBatchEmbeddings",
     "AsyncBatchResponses",
     "BatchEmbeddings",
     "BatchResponses",
+    "FewShotPrompt",
     "FewShotPromptBuilder",
+    "SchemaInferenceOutput",
     "PreparedTask",
+    "SchemaInferenceInput",
+    "SchemaInferer",
 ]
