@@ -130,35 +130,9 @@ def provide_async_openai_client() -> AsyncOpenAI:
     )
 
 
-CONTAINER.register(ResponsesModelName, lambda: ResponsesModelName("gpt-4.1-mini"))
-CONTAINER.register(EmbeddingsModelName, lambda: EmbeddingsModelName("text-embedding-3-small"))
-CONTAINER.register(OpenAIAPIKey, lambda: OpenAIAPIKey(os.getenv("OPENAI_API_KEY")))
-CONTAINER.register(AzureOpenAIAPIKey, lambda: AzureOpenAIAPIKey(os.getenv("AZURE_OPENAI_API_KEY")))
-CONTAINER.register(AzureOpenAIBaseURL, lambda: AzureOpenAIBaseURL(os.getenv("AZURE_OPENAI_BASE_URL")))
-CONTAINER.register(
-    cls=AzureOpenAIAPIVersion,
-    provider=lambda: AzureOpenAIAPIVersion(os.getenv("AZURE_OPENAI_API_VERSION", "preview")),
-)
-CONTAINER.register(OpenAI, provide_openai_client)
-CONTAINER.register(AsyncOpenAI, provide_async_openai_client)
-CONTAINER.register(tiktoken.Encoding, lambda: tiktoken.get_encoding("o200k_base"))
-CONTAINER.register(TextChunker, lambda: TextChunker(CONTAINER.resolve(tiktoken.Encoding)))
-CONTAINER.register(
-    SchemaInferer,
-    lambda: SchemaInferer(
-        client=CONTAINER.resolve(OpenAI),
-        model_name=CONTAINER.resolve(ResponsesModelName).value,
-    ),
-)
-
-
-def reset_environment_registrations():
-    """Reset environment variable related registrations in the container.
-
-    This function re-registers environment variable dependent services to pick up
-    current environment variable values. Useful for testing when environment
-    variables are changed after initial container setup.
-    """
+def set_default_registrations():
+    CONTAINER.register(ResponsesModelName, lambda: ResponsesModelName("gpt-4.1-mini"))
+    CONTAINER.register(EmbeddingsModelName, lambda: EmbeddingsModelName("text-embedding-3-small"))
     CONTAINER.register(OpenAIAPIKey, lambda: OpenAIAPIKey(os.getenv("OPENAI_API_KEY")))
     CONTAINER.register(AzureOpenAIAPIKey, lambda: AzureOpenAIAPIKey(os.getenv("AZURE_OPENAI_API_KEY")))
     CONTAINER.register(AzureOpenAIBaseURL, lambda: AzureOpenAIBaseURL(os.getenv("AZURE_OPENAI_BASE_URL")))
@@ -168,6 +142,8 @@ def reset_environment_registrations():
     )
     CONTAINER.register(OpenAI, provide_openai_client)
     CONTAINER.register(AsyncOpenAI, provide_async_openai_client)
+    CONTAINER.register(tiktoken.Encoding, lambda: tiktoken.get_encoding("o200k_base"))
+    CONTAINER.register(TextChunker, lambda: TextChunker(CONTAINER.resolve(tiktoken.Encoding)))
     CONTAINER.register(
         SchemaInferer,
         lambda: SchemaInferer(
@@ -175,3 +151,6 @@ def reset_environment_registrations():
             model_name=CONTAINER.resolve(ResponsesModelName).value,
         ),
     )
+
+
+set_default_registrations()
