@@ -9,7 +9,7 @@ Example:
 
     ```python
     from openai import OpenAI
-    from openaivec._responses import BatchResponses
+    from openaivec import BatchResponses
     from openaivec.task import customer_support
 
     client = OpenAI()
@@ -92,8 +92,7 @@ def response_suggestion(
     response_style: str = "professional",
     company_name: str = "our company",
     business_context: str = "general customer support",
-    temperature: float = 0.0,
-    top_p: float = 1.0,
+    **api_kwargs,
 ) -> PreparedTask:
     """Create a configurable response suggestion task.
 
@@ -101,8 +100,8 @@ def response_suggestion(
         response_style (str): Style of response (professional, friendly, empathetic, formal).
         company_name (str): Name of the company for personalization.
         business_context (str): Business context for responses.
-        temperature (float): Sampling temperature (0.0-1.0).
-        top_p (float): Nucleus sampling parameter (0.0-1.0).
+        **api_kwargs: Additional keyword arguments to pass to the OpenAI API,
+            such as temperature, top_p, etc.
 
     Returns:
         PreparedTask configured for response suggestions.
@@ -190,10 +189,8 @@ but use English values like "empathetic" for tone.
 Generate helpful, professional response that moves toward resolution while maintaining
 positive customer relationship."""
 
-    return PreparedTask(
-        instructions=instructions, response_format=ResponseSuggestion, temperature=temperature, top_p=top_p
-    )
+    return PreparedTask(instructions=instructions, response_format=ResponseSuggestion, api_kwargs=api_kwargs)
 
 
 # Backward compatibility - default configuration
-RESPONSE_SUGGESTION = response_suggestion()
+RESPONSE_SUGGESTION = response_suggestion(temperature=0.0, top_p=1.0)
