@@ -8,7 +8,7 @@ Example:
 
     ```python
     from openai import OpenAI
-    from openaivec._responses import BatchResponses
+    from openaivec import BatchResponses
     from openaivec.task import nlp
 
     client = OpenAI()
@@ -75,6 +75,5 @@ DEPENDENCY_PARSING = PreparedTask(
     "relations between words, determine the root word, and provide a tree representation of the "
     "syntactic structure.",
     response_format=DependencyParsing,
-    temperature=0.0,
-    top_p=1.0,
+    api_kwargs={"temperature": 0.0, "top_p": 1.0},
 )
