@@ -33,7 +33,7 @@ Example:
 
     ```python
     from openai import OpenAI
-    from openaivec._responses import BatchResponses
+    from openaivec import BatchResponses
     from openaivec.task.table import fillna
 
     client = OpenAI()
@@ -125,7 +125,7 @@ class FillNaResponse(BaseModel):
     )
 
 
-def fillna(df: pd.DataFrame, target_column_name: str, max_examples: int = 500) -> PreparedTask:
+def fillna(df: pd.DataFrame, target_column_name: str, max_examples: int = 500, **api_kwargs) -> PreparedTask:
     """Create a prepared task for filling missing values in a DataFrame column.
 
     Analyzes the provided DataFrame to understand data patterns and creates
@@ -141,12 +141,14 @@ def fillna(df: pd.DataFrame, target_column_name: str, max_examples: int = 500) -
         max_examples (int): Maximum number of example rows to use for few-shot
             learning. Defaults to 500. Higher values provide more context
             but increase token usage and processing time.
+        **api_kwargs: Additional keyword arguments to pass to the OpenAI API,
+            such as temperature, top_p, etc.
 
     Returns:
         PreparedTask configured for missing value imputation with:
         - Instructions based on DataFrame patterns
         - FillNaResponse format for structured output
-        - Temperature=0.0 and top_p=1.0 for deterministic results
+        - Default deterministic settings (temperature=0.0, top_p=1.0)
 
     Raises:
         ValueError: If target_column_name doesn't exist in DataFrame,
@@ -180,4 +182,7 @@ def fillna(df: pd.DataFrame, target_column_name: str, max_examples: int = 500) -
     if df[target_column_name].notna().sum() == 0:
         raise ValueError(f"Column '{target_column_name}' contains no non-null values for training examples.")
     instructions = get_instructions(df, target_column_name, max_examples)
-    return PreparedTask(instructions=instructions, response_format=FillNaResponse, temperature=0.0, top_p=1.0)
+    # Set default values for deterministic results if not provided
+    if not api_kwargs:
+        api_kwargs = {"temperature": 0.0, "top_p": 1.0}
+    return PreparedTask(instructions=instructions, response_format=FillNaResponse, api_kwargs=api_kwargs)
