@@ -1,8 +1,6 @@
-import asyncio
 from logging import Handler, StreamHandler, basicConfig
-from unittest import TestCase
 
-from openai import AsyncOpenAI, OpenAI
+import pytest
 from pydantic import BaseModel
 
 from openaivec import BatchResponses
@@ -13,10 +11,13 @@ _h: Handler = StreamHandler()
 basicConfig(handlers=[_h], level="DEBUG")
 
 
-class TestVectorizedResponsesOpenAI(TestCase):
-    def setUp(self):
-        self.openai_client = OpenAI()
-        self.model_name = "gpt-4.1-mini"
+@pytest.mark.requires_api
+class TestVectorizedResponsesOpenAI:
+    @pytest.fixture(autouse=True)
+    def setup_client(self, openai_client, responses_model_name):
+        self.openai_client = openai_client
+        self.model_name = responses_model_name
+        yield
 
     def test_predict_str(self):
         system_message = """
@@ -29,7 +30,7 @@ class TestVectorizedResponsesOpenAI(TestCase):
         )
         response: list[str] = client._predict_chunk(["hello", "world"])
 
-        self.assertEqual(response, ["hello", "world"])
+        assert response == ["hello", "world"]
 
     def test_predict_structured(self):
         system_message = """
@@ -39,11 +40,11 @@ class TestVectorizedResponsesOpenAI(TestCase):
         apple
 
         ## output
-        {{
+        {
             "name": "apple",
             "color": "red",
             "taste": "sweet"
-        }}
+        }
         """
 
         class Fruit(BaseModel):
@@ -57,15 +58,35 @@ class TestVectorizedResponsesOpenAI(TestCase):
 
         response: list[Fruit] = client._predict_chunk(["apple", "banana"])
 
-        self.assertTrue(all(isinstance(item, Fruit) for item in response))
+        assert all(isinstance(item, Fruit) for item in response)
+
+    @pytest.mark.parametrize("batch_size", [1, 2, 4])
+    def test_predict_with_batch_sizes(self, batch_size):
+        """Test BatchResponses with different batch sizes."""
+        system_message = "just repeat the user message"
+        client = BatchResponses(
+            client=self.openai_client,
+            model_name=self.model_name,
+            system_message=system_message,
+        )
+
+        test_inputs = ["test1", "test2", "test3", "test4"][:batch_size]
+        response: list[str] = client._predict_chunk(test_inputs)
+
+        assert len(response) == len(test_inputs)
+        assert all(isinstance(item, str) for item in response)
 
 
-class TestAsyncBatchResponses(TestCase):
-    def setUp(self):
-        self.openai_client = AsyncOpenAI()
-        self.model_name = "gpt-4.1-nano"
+@pytest.mark.requires_api
+class TestAsyncBatchResponses:
+    @pytest.fixture(autouse=True)
+    def setup_client(self, async_openai_client):
+        self.openai_client = async_openai_client
+        self.model_name = "gpt-4.1-mini"
+        yield
 
-    def test_parse_str(self):
+    @pytest.mark.asyncio
+    async def test_parse_str(self):
         system_message = """
         just repeat the user message
         """.strip()
@@ -75,10 +96,11 @@ class TestAsyncBatchResponses(TestCase):
             system_message=system_message,
             batch_size=1,
         )
-        response: list[str] = asyncio.run(client.parse(["apple", "orange", "banana", "pineapple"]))
-        self.assertListEqual(response, ["apple", "orange", "banana", "pineapple"])
+        response: list[str] = await client.parse(["apple", "orange", "banana", "pineapple"])
+        assert response == ["apple", "orange", "banana", "pineapple"]
 
-    def test_parse_structured(self):
+    @pytest.mark.asyncio
+    async def test_parse_structured(self):
         system_message = """
         return the color and taste of given fruit
         #example
@@ -106,17 +128,18 @@ class TestAsyncBatchResponses(TestCase):
             response_format=Fruit,
             batch_size=1,
         )
-        response: list[Fruit] = asyncio.run(client.parse(input_fruits))
-        self.assertEqual(len(response), len(input_fruits))
+        response: list[Fruit] = await client.parse(input_fruits)
+        assert len(response) == len(input_fruits)
         for i, item in enumerate(response):
-            self.assertIsInstance(item, Fruit)
-            self.assertEqual(item.name.lower(), input_fruits[i].lower())
-            self.assertIsInstance(item.color, str)
-            self.assertTrue(len(item.color) > 0)
-            self.assertIsInstance(item.taste, str)
-            self.assertTrue(len(item.taste) > 0)
+            assert isinstance(item, Fruit)
+            assert item.name.lower() == input_fruits[i].lower()
+            assert isinstance(item.color, str)
+            assert len(item.color) > 0
+            assert isinstance(item.taste, str)
+            assert len(item.taste) > 0
 
-    def test_parse_structured_empty_input(self):
+    @pytest.mark.asyncio
+    async def test_parse_structured_empty_input(self):
         system_message = """
         return the color and taste of given fruit
         """
@@ -133,10 +156,11 @@ class TestAsyncBatchResponses(TestCase):
             response_format=Fruit,
             batch_size=1,
         )
-        response: list[Fruit] = asyncio.run(client.parse([]))
-        self.assertListEqual(response, [])
+        response: list[Fruit] = await client.parse([])
+        assert response == []
 
-    def test_parse_structured_batch_size(self):
+    @pytest.mark.asyncio
+    async def test_parse_structured_batch_size(self):
         system_message = """
         return the color and taste of given fruit
         #example
@@ -164,15 +188,15 @@ class TestAsyncBatchResponses(TestCase):
             response_format=Fruit,
             batch_size=2,
         )
-        response_bs2: list[Fruit] = asyncio.run(client_bs2.parse(input_fruits))
-        self.assertEqual(len(response_bs2), len(input_fruits))
+        response_bs2: list[Fruit] = await client_bs2.parse(input_fruits)
+        assert len(response_bs2) == len(input_fruits)
         for i, item in enumerate(response_bs2):
-            self.assertIsInstance(item, Fruit)
-            self.assertEqual(item.name.lower(), input_fruits[i].lower())
-            self.assertIsInstance(item.color, str)
-            self.assertTrue(len(item.color) > 0)
-            self.assertIsInstance(item.taste, str)
-            self.assertTrue(len(item.taste) > 0)
+            assert isinstance(item, Fruit)
+            assert item.name.lower() == input_fruits[i].lower()
+            assert isinstance(item.color, str)
+            assert len(item.color) > 0
+            assert isinstance(item.taste, str)
+            assert len(item.taste) > 0
 
         client_bs4 = AsyncBatchResponses.of(
             client=self.openai_client,
@@ -181,12 +205,12 @@ class TestAsyncBatchResponses(TestCase):
             response_format=Fruit,
             batch_size=4,
         )
-        response_bs4: list[Fruit] = asyncio.run(client_bs4.parse(input_fruits))
-        self.assertEqual(len(response_bs4), len(input_fruits))
+        response_bs4: list[Fruit] = await client_bs4.parse(input_fruits)
+        assert len(response_bs4) == len(input_fruits)
         for i, item in enumerate(response_bs4):
-            self.assertIsInstance(item, Fruit)
-            self.assertEqual(item.name.lower(), input_fruits[i].lower())
-            self.assertIsInstance(item.color, str)
-            self.assertTrue(len(item.color) > 0)
-            self.assertIsInstance(item.taste, str)
-            self.assertTrue(len(item.taste) > 0)
+            assert isinstance(item, Fruit)
+            assert item.name.lower() == input_fruits[i].lower()
+            assert isinstance(item.color, str)
+            assert len(item.color) > 0
+            assert isinstance(item.taste, str)
+            assert len(item.taste) > 0
